@@ -23,16 +23,16 @@
 
 #include <QApplication>
 #include "settings.h"
-#include <libfm-qt/libfmqt.h>
-#include <libfm-qt/editbookmarksdialog.h>
+#include <libfm-qt6/libfmqt.h>
+#include <libfm-qt6/editbookmarksdialog.h>
 #include <QVector>
 #include <QPointer>
 #include <QProxyStyle>
 #include <QTranslator>
 #include <gio/gio.h>
 
-#include <libfm-qt/core/filepath.h>
-#include <libfm-qt/core/fileinfo.h>
+#include <libfm-qt6/core/filepath.h>
+#include <libfm-qt6/core/fileinfo.h>
 
 class QScreen;
 
@@ -130,7 +130,7 @@ protected Q_SLOTS:
 protected:
     //virtual bool eventFilter(QObject* watched, QEvent* event);
     bool parseCommandLineArgs();
-    DesktopWindow* createDesktopWindow(int screenNum);
+    DesktopWindow* createDesktopWindow(int screenNum, const QString& screenName = QString());
     bool autoMountVolume(GVolume* volume, bool interactive = true);
 
     static void onVolumeAdded(GVolumeMonitor* monitor, GVolume* volume, Application* pThis);
