@@ -24,6 +24,7 @@
 #include <QApplication>
 #include <QDrag>
 #include <QMimeData>
+#include <algorithm>
 
 namespace PCManFM {
 
@@ -34,6 +35,7 @@ TabBar::TabBar(QWidget *parent):
     dragStarted_(false),
     detachable_(true)
 {
+    setElideMode(Qt::ElideRight); // works with minimumTabSizeHint()
 }
 
 void TabBar::mousePressEvent(QMouseEvent *event) {
@@ -142,6 +144,26 @@ void TabBar::dragEnterEvent(QDragEnterEvent *event) {
     }
 }
 
+// Limit the size of large tabs to 2/3 of the width of the tabbar.
+QSize TabBar::tabSizeHint(int index) const {
+    switch (shape()) {
+    case QTabBar::RoundedWest:
+    case QTabBar::TriangularWest:
+    case QTabBar::RoundedEast:
+    case QTabBar::TriangularEast:
+        return QSize(QTabBar::tabSizeHint(index).width(),
+                     std::min(2 * height() / 3, QTabBar::tabSizeHint(index).height()));
+    default:
+        return QSize(std::min(2 * width() / 3, QTabBar::tabSizeHint(index).width()),
+                     QTabBar::tabSizeHint(index).height());
+    }
+}
+
+// Set minimumTabSizeHint to tabSizeHint to keep tabs from shrinking with eliding.
+QSize TabBar::minimumTabSizeHint(int index) const {
+    return tabSizeHint(index);
+}
+
 void TabBar::tabInserted(int index) {
     // WARNING: Qt6 has a bug that does not show the tabbar in our window on inserting the first
     // tab unless the tab layout is updated after its insertion. Usually, the tab text is reset
